Welcome to VillageWars!

Here's some info on how to play this game successfully.

First, you need to install python at https://www.python.org/ftp/python/3.10.6/python-3.10.6-amd64.exe
If python is already installed, move on.

Last of all, when running the server for VillageWars, the computer has to access and give information through port 5555. If you can customize your firewall to let this port be used by python, then great. Otherwise you'll have to turn off the firewall temporarily while running the server.

You should be good to go!

Quickstart:

>>> import villagewars

This will run the client.

To start the server, hotkey alt-M and search villagewars. Then hotkey ctrl-O and and open ./src/VillageWarsServer.py